@@ -340,8 +340,8 @@ class DataTransformer(MPTTModel):
     type = models.ForeignKey(DataTransformerTypes, on_delete=models.DO_NOTHING, blank=True, null=True, default=None)
 
     parent = TreeForeignKey('self', on_delete=models.CASCADE, null=True, blank=True, related_name='children')
-    updated_at = models.DateTimeField(auto_now=True)
-    created_at = models.DateTimeField(auto_now_add=True)
+    updated_at = models.DateTimeField(blank=True,auto_now=True)
+    created_at = models.DateTimeField(blank=True,auto_now_add=True)
 
     def save(self, *args, **kwargs):
         if not self.created_at:
@@ -360,11 +360,10 @@ class DataTransformer(MPTTModel):
 
 
 class DataTransformerConstants(models.Model):
-    id = models.UUIDField(primary_key=True, default=uuid.uuid4)
+    id = models.UUIDField(primary_key=True, default=uuid.uuid4,blank=True,null=False)
     data_transformer = models.ForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True, default=None)
-    type = models.CharField(max_length=255, null=True)
-    index = models.IntegerField()
-    value = models.FloatField(null=True)
+    index = models.IntegerField(blank=True,null=True)
+    value = models.FloatField(blank=True,null=False)
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
 
@@ -383,11 +382,11 @@ class DataTransformerConstants(models.Model):
 
 class HardwareDataTransformer(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
-    hardware = models.ManyToManyField(Channel)
+    hardware = models.ManyToManyField(Channel,blank=True,null=False)
     data_transformer = models.ForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True, default=None)
     index = models.IntegerField(blank=True, null=True, default=None)
-    updated_at = models.DateTimeField(auto_now=True)
-    created_at = models.DateTimeField(auto_now_add=True)
+    updated_at = models.DateTimeField(blank=True,auto_now=True)
+    created_at = models.DateTimeField(blank=True,auto_now_add=True)
 
     def save(self, *args, **kwargs):
         if not self.created_at:
@@ -403,12 +402,12 @@ class HardwareDataTransformer(models.Model):
 
 
 class HardwareStatsDataTransformer(models.Model):
-    id = models.UUIDField(primary_key=True, default=uuid.uuid4)
+    id = models.UUIDField(primary_key=True, default=uuid.uuid4,blank=True,null=False)
     hardware_stat = models.ForeignKey(HardwareStats, on_delete=models.CASCADE, blank=True, null=True, default=None)
     data_transformer = models.ForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True, default=None)
     index = models.IntegerField()
-    updated_at = models.DateTimeField(auto_now=True)
-    created_at = models.DateTimeField(auto_now_add=True)
+    updated_at = models.DateTimeField(blank=True,auto_now=True)
+    created_at = models.DateTimeField(blank=True,auto_now_add=True)
 
     def save(self, *args, **kwargs):
         if not self.created_at:
