@@ -1,4 +1,5 @@
 import json
+from collections import defaultdict
 
 from django.core import serializers as django_serializers
 from django.forms import formset_factory, inlineformset_factory
@@ -365,6 +366,7 @@ class HardwareViewSet(viewsets.ModelViewSet):
 
 from data.forms.forms import DataTransform, DataTransformRoot
 from data.models.models import DataTransformer
+from data.serializers.serializers import DataTransformerTreeSerializer
 
 
 class AccessoryViewSet(viewsets.ModelViewSet):
@@ -434,14 +436,20 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         print(str(request.POST))
         print('post data transformer')
         # request should be ajax and method should be POST.
-        form = DataTransformRoot(request.POST)
-        instance = form.save()
-        print(str(instance))
-        # serialize in new friend object in json
-        ser_instance = django_serializers.serialize('json', [instance, ])
-        print(str(ser_instance))
-        # send to client side.
-        return JsonResponse({"instance": ser_instance}, status=200)
+        form = DataTransformRoot(instance=DataTransformer.objects.get(pk=request.POST['id']),
+                             data=request.POST)
+        data_transformer_root = form.save()
+        data_transformer_family = data_transformer_root.get_family()
+        children_dict = defaultdict(list)
+        for descendant in data_transformer_family:
+            children_dict[descendant.get_parent().pk].append(descendant)
+
+        context = {}
+        context['children'] = children_dict
+        serializer = DataTransformerTreeSerializer(data_transformer_root, context=context)
+        print(str(serializer.data))
+
+        return JsonResponse({"instance": serializer.data}, status=200)
 
 
     def postCalibration(request):
